# -*- coding: utf-8 -*-

from datetime import datetime
import argparse
import common


def datefmt():
    """ Get adapted date format """
    today = datetime.today()
    return today.strftime('%Y-%m-%d_%Hh%Mm%Ss')


def dump(odoo, bakpath, password, dbname):
    """ Dumps a database """
    dump = odoo.db.dump(password, dbname)
    fpath = '{bakpath}/{date}_{dbname}.zip'.format(bakpath=bakpath,
                                                   dbname=dbname,
                                                   date=datefmt())
    with open(fpath, 'wb') as zipf:
        zipf.write(dump.read())
    return fpath


def dump_all(odoo, bakpath, password):
    """ Dump all databases """
    return [dump(bakpath, password, db) for db in odoo.db.list()]


def main():
    """ Main function with argument parsing """
    parser = argparse.ArgumentParser(description='Backup Odoo databases')
    parser = common.parser(parser)
    parser.add_argument('-pw', '--password', type=str, required=True,
                        help='the odoo master password')
    parser.add_argument('-D', '--directory', type=str, required=True,
                        help='the directory path where to save backups')
    parser.add_argument('-n', '--name', type=str,
                        help='optional database name (default:all)')
    args = parser.parse_args()

    # Connection
    odoo = common.connection(args)

    # Backup actions
    if not args.name:
        dump_all(odoo, args.directory, args.password)
    else:
        dump(odoo, args.directory, args.password, args.name)

if __name__ == "__main__":
    main()
